# frozen_string_literal: true

module VcsTypeHelper
  SHORT_LABELS = {
    hg_git: "hg (legacy)",
    git: "git",
    hg: "hg"
  }.freeze

  def vcs_type_all_options
    {
      s_('VcsType|Mercurial') => 'hg',
      s_('VcsType|Git') => 'git',
      s_('VcsType|Mercurial (legacy with Git conversion)') => 'hg_git'
    }
  end

  def vcs_type_enabled_options
    enabled = ::Gitlab::CurrentSettings.current_application_settings.vcs_types
    vcs_type_all_options.select { |k, v| enabled.include?(v) }
  end

  def vcs_type_git_allowed?
    ::Gitlab::CurrentSettings.current_application_settings.vcs_types.include?("git")
  end

  def vcs_type_short_label(project)
    SHORT_LABELS.fetch(project.vcs_type.to_sym)
  end

  def vcs_type_default(project)
    return project.group.default_vcs_type unless project.group.nil?

    ::Gitlab::CurrentSettings.current_application_settings.default_vcs_type
  end
end
