# frozen_string_literal: true

module Heptapod
  class NativeMigrationLog < Heptapod::ApplicationRecord
    belongs_to :project, optional: false

    state_machine :state, initial: :running do
      state :running
      state :finished
    end

    class << self
      def version_field_value(major, minor, patch)
        major * 10000 + minor * 100 + patch
      end

      def current_version_field_value
        info = Gitlab.heptapod_version_info
        version_field_value(info.major, info.minor, info.patch)
      end

      def start(project)
        create!(project: project,
                heptapod_version: current_version_field_value,
                rollbackable: true)
      end

      # tell whether there is a migration process currently
      # running for the given project.
      def running?(project)
        where(project: project, state: "running").count > 0
      end
    end
  end
end
