# frozen_string_literal: true

class AddHgMirrorTypeToRemoteMirrors < Gitlab::Database::Migration[2.0]
  include Gitlab::Database::MigrationHelpers

  DOWNTIME = false

  disable_ddl_transaction!

  HPD_TABLE = :remote_mirrors
  HPD_COLUMN = :hg_mirror_type

  def up
    return if column_exists?(HPD_TABLE, HPD_COLUMN)

    # limits on the text data type are pretty useless in PostgreSQL, unless
    # we really want to restrict some user input instead of using a few
    # curated values (we'd better add a constraint for the possible values instead)
    # rubocop:disable Migration/AddLimitToTextColumns
    add_column(HPD_TABLE, HPD_COLUMN, :text, allow_null: true)
    # rubocop:enable Migration/AddLimitToTextColumns
  end

  def down
    remove_column(HPD_TABLE, HPD_COLUMN) if column_exists?(HPD_TABLE, HPD_COLUMN)
  end
end
