# frozen_string_literal: true

# See https://docs.gitlab.com/ee/development/migration_style_guide.html
# for more information on how to write migrations for GitLab.

class AddHgLegacyGitConversionToProject < Gitlab::Database::Migration[2.0]
  enable_lock_retries!

  # We could have this flag in the separate `project_settings` table.
  # However, it would mean paying the added cost of the join (in best case) each time
  # a `Repository` object has to be instantiated, and that happens a lot,
  # sometimes for a tiny operation. So we're making an exception for this one.
  # It should be replaced by something else when Heptapod provides asynchronous
  # conversions to Git (e.g., as part of the Git mirror push).
  # rubocop:disable Migration/AddColumnsToWideTables
  def up
    add_column :projects, :hg_legacy_git_conversion, :boolean
  end
  # rubocop:enable Migration/AddColumnsToWideTables

  def down
    # no-op: we don't want to lose data that has potentially been filled in by end users.
    # keeping the column does no harm when downgrading GitLab/Heptapod versions
  end
end
