# frozen_string_literal: true
module Gitlab
  module BackgroundMigration
    # Backfill the `hg_legacy_git_conversion` boolean attribute of `Project`.
    #
    # This migration runs for native Mercurial projects only.
    # The attribute is set to true if the projects has a Git push mirror.
    class BackfillProjectHgLegacyGitConversion < BatchedMigrationJob
      scope_to ->(relation) { relation.where(vcs_type: 'hg') }

      # Simplified Model, to use the bare ORM
      class RemoteMirror < ::ApplicationRecord
        self.table_name = 'remote_mirrors'
      end

      def perform
        each_sub_batch(operation_name: :backfill_hg_legacy_git_conversion) do |sub_batch|
          backfill_hg_legacy_git_conversion(sub_batch)
        end
      end

      private

      def backfill_hg_legacy_git_conversion(relation)
        relation.each do |project|
          project.hg_legacy_git_conversion = !RemoteMirror.find_by(project_id: project.id, 'hg_mirror_type': nil).nil?
          project.save!
        end
      end
    end
  end
end
