# frozen_string_literal: true

module Gitlab
  module GitalyClient
    class MercurialChangesetService
      include Gitlab::EncodingHelper

      # 'repository' is a Mercurial subclass of Gitlab::Git::Repository
      def initialize(repository)
        @repository = repository
        @gitaly_repo = repository.gitaly_repository
        @storage = Gitlab::GitalyClient.vcs_qualified_storage(
          repository.storage, 'hg')
      end

      def obsolete?(changeset_id)
        request = Hgitaly::ListMercurialChangesetsRequest.new(
          repository: @gitaly_repo,
          view: Hgitaly::MercurialRepositoryView::UNFILTERED,
          fields: [Hgitaly::MercurialChangesetField::OBSOLETE],
          revset: changeset_id
        )
        response = GitalyClient.call(
          @storage, :mercurial_changeset_service, :list_mercurial_changesets, request,
          timeout: GitalyClient.fast_timeout
        )
        response.first.changesets[0].obsolete
      end
    end
  end
end
