# frozen_string_literal: true

module Gitlab
  module GitalyClient
    # RHGitaly awareness for client service classes
    #
    # Service classes including this module can use the `#rhgitaly_storage_or`
    # method to call RHGitaly when HGitaly would otherwise have been called.
    # This system amounts for the fact that only a few gRPC methods are
    # implemented in RHGitaly. It is ideally in the future to be replaced by
    # a transparent fallbacking proxy system.
    #
    # This module is self-contained enough for the use of instance variables to
    # be acceptable (see https://docs.gitlab.com/ce/development/module_with_instance_variables.html)
    # rubocop:disable Gitlab/ModuleWithInstanceVariables
    module RhgitalyAware
      def init_rhgitaly(repository, vcs)
        return if vcs != 'hg' || !Feature.enabled?(:rhgitaly)

        @rhgitaly_storage = Gitlab::GitalyClient.vcs_qualified_storage(repository.storage, "rhg")
      end

      def rhgitaly_storage_or(storage)
        @rhgitaly_storage.nil? ? storage : @rhgitaly_storage
      end
    end
    # rubocop:enable Gitlab/ModuleWithInstanceVariables
  end
end
