# frozen_string_literal: true

require 'spec_helper'
RSpec.describe Gitlab::BackgroundMigration::BackfillProjectHgLegacyGitConversion, :migration do
  let(:migration) do
    described_class.new(
      start_id: 1,
      end_id: table(:projects).maximum(:id),
      batch_table: :projects,
      batch_column: :id,
      sub_batch_size: 2,
      pause_ms: 0,
      connection: ApplicationRecord.connection
    )
  end

  let(:namespaces_table) { table(:namespaces) }
  let(:projects_table) { table(:projects) }
  let(:mirrors_table) { table(:remote_mirrors) }

  subject(:perform_migration) { migration.perform }

  before do
    def create_project(id, vcs_type)
      namespace_id = id / 10
      slug_id = id % 10
      namespaces_table.create!(id: id,
                               name: "project-ns-#{id}",
                               path: "project-ns-#{id}",
                               type: 'Project')
      projects_table.create!(id: id,
                             name: "group-project-#{slug_id}",
                             path: "group-project-path-#{slug_id}",
                             namespace_id: namespace_id,
                             vcs_type: vcs_type,
                             project_namespace_id: id)
    end

    namespaces_table.create!(id: 1, name: 'namespace', path: 'namespace-path', type: 'Group')
    create_project(11, 'hg')
    create_project(12, 'hg')
    mirrors_table.create!(project_id: 11, hg_mirror_type: 'hg-pull')

    namespaces_table.create!(id: 2, name: 'namespace', path: 'namespace-path', type: 'User')
    create_project(21, 'hg')
    create_project(22, 'hg')
    create_project(23, 'git')
    mirrors_table.create!(project_id: 22, hg_mirror_type: nil)
    mirrors_table.create!(project_id: 23, hg_mirror_type: nil)

    namespaces_table.create!(id: 3, name: 'namespace', path: 'namespace-path', type: 'Group')
    create_project(31, 'hg') # project with 2 mirrors, one of them being Git push
    mirrors_table.create!(project_id: 31, hg_mirror_type: nil)
    mirrors_table.create!(project_id: 31, hg_mirror_type: 'hg-push')
  end

  it 'backfills hg_legacy_git_conversion to True if and only if the project has a Git push remote mirror' do
    perform_migration

    expect(mirrors_table.count).to eq 5
    expect(projects_table.count).to eq 6
    expect(projects_table.where(hg_legacy_git_conversion: false).count).to eq(3)
    expect(projects_table.where(hg_legacy_git_conversion: true).map(&:id).sort).to eq([22, 31])
    expect(projects_table.where(hg_legacy_git_conversion: nil).map(&:id)).to eq([23])
  end
end
