# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Heptapod::NativeMigrationLog do
  let(:project) { create(:hg_git_project) }

  describe 'class method' do
    it 'version_field_value is as expected' do
      expect(described_class.version_field_value(0, 29, 2)).to eq(2902)
      expect(described_class.version_field_value(1, 2, 2)).to eq(10202)
    end

    it 'current_version_field_value works' do
      expect(described_class.current_version_field_value).to be >= 3000
    end

    it "create creates a new record" do
      record = described_class.start(project)
      expect(record.rollbackable).to be true
    end
  end

  describe "state machine" do
    subject { described_class.start(project) }

    it "starts in running state, and progresses from there" do
      expect(subject.state).to eq("running")

      expect(subject.running?).to be true
      subject.state = :finished
      expect(subject.running?).to be false
    end

    it "has a finished state" do
      subject.state = :finished
      expect(subject.state).to eq("finished")
    end

    it "cannot have unknown state" do
      subject.state = :unknown
      expect { subject.save! }.to raise_error(ActiveRecord::RecordInvalid)
    end
  end
end
