# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Project and Repository models with vcs_type="hg_git"', factory_default: :keep do
  let(:project) do
    allow_next_instance_of(Project) do |project|
      allow(project).to receive(:check_vcs_type).and_return(true)
    end
    create(:hg_git_project)
  end

  let(:raw_repo) { project.repository.raw_repository }

  describe 'raw repository' do
    it 'is not HGitaly' do
      expect(raw_repo).to be_instance_of(Gitlab::Mercurial::HgGitRepository)
      expect(raw_repo).not_to be_instance_of(Gitlab::Mercurial::HgitalyRepository)
    end
  end

  describe '#mercurial?' do
    it 'is true' do
      expect(project.mercurial?).to be(true)
    end
  end

  describe '#hg_native_migration_in_progress?' do
    let(:project) { create(:hg_git_project) }

    it "is false when migration is not running" do
      expect(project.hg_native_migration_in_progress?).to be false
    end

    it "is true if migration is running, until finished" do
      Heptapod::NativeMercurial::Migrator.new(project, project.creator).enter do
        expect(project.hg_native_migration_in_progress?).to be true
      end
      expect(project.hg_native_migration_in_progress?).to be false
    end
  end
end
