# frozen_string_literal: true

require 'spec_helper'

RSpec.describe API::HeptapodVersion do
  context 'when unauthenticated' do
    it 'returns authentication error' do
      get api('/heptapod_version')

      expect(response).to have_gitlab_http_status(:unauthorized)
    end
  end

  context 'when authenticated as user' do
    let(:user) { create(:user) }

    it 'returns the version information' do
      get api('/heptapod_version', user)

      expect_heptapod_versions
    end
  end

  context 'when authenticated with token' do
    let(:personal_access_token) { create(:personal_access_token, scopes: scopes) }

    context 'with api scope' do
      let(:scopes) { %i[api] }

      it 'returns the version information' do
        get api('/heptapod_version', personal_access_token: personal_access_token)

        expect_heptapod_versions
      end

      it 'returns "200" response on head requests' do
        head api('/heptapod_version', personal_access_token: personal_access_token)

        expect(response).to have_gitlab_http_status(:ok)
      end
    end

    context 'with read_user scope' do
      let(:scopes) { %i[read_user] }

      it 'returns the version information' do
        get api('/heptapod_version', personal_access_token: personal_access_token)

        expect_heptapod_versions
      end

      it 'returns "200" response on head requests' do
        head api('/heptapod_version', personal_access_token: personal_access_token)

        expect(response).to have_gitlab_http_status(:ok)
      end
    end

    context 'with neither api nor read_user scope' do
      let(:scopes) { %i[read_repository] }

      it 'returns authorization error' do
        get api('/heptapod_version', personal_access_token: personal_access_token)

        expect(response).to have_gitlab_http_status(:forbidden)
      end
    end
  end

  def expect_heptapod_versions
    expect(response).to have_gitlab_http_status(:ok)
    expect(json_response['heptapod']).to eq(Gitlab::HEPTAPOD_VERSION)
    expect(json_response['mercurial']).to eq(Gitlab.python_versions['mercurial'])
    expect(json_response['python']).to eq(Gitlab.python_versions['python'])
    expect(json_response['evolve']).to eq(Gitlab.python_versions['evolve'])
  end
end
